@@ -422,7 +422,7 @@ def plotComparisons(inputdata, dataplot,
 	return
 
 #################################################
-def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None):
+def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None, stackTT = True):
 	"""
 	Function to plot Time-Temperature paths
 
@@ -434,6 +434,8 @@ def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None
 		                           Defaults to 'Graphs'.
 		graphtitle (str, optional): Title of the graph.
 		                            Defaults to None.
+		stackTT (boolean, optional): Tells if we want to plot all the PTt path in one single graph
+									 Defaults to True
 	"""
 
 	# Read the inputdataPTt (.csv) file
@@ -478,9 +480,9 @@ def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None
 	indexPTt = np.where(np.isnan(inputPTt['LAT']) == False)[0]
 	
 	if nPTtsamples > 0:
-		fig3 = plt.figure()
 		# For each sample with PT-t, 
 		for k in range (0, nPTtsamples):
+			fig3 = plt.figure(3)
 			#	Extract the PTt path from the file
 			if k == (nPTtsamples-1):
 				ppt = inputPTt[['TIMEH', 'TEMPH', 'DTEMPH']][indexPTt[k]:]
@@ -489,7 +491,7 @@ def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None
 				ppt = inputPTt[['TIMEH', 'TEMPH', 'DTEMPH']][indexPTt[k]:indexPTt[k + 1]]
 				pptOut = outputPTt[['TIME', 'TEMP', 'TEMPPRED']][indexPTt[k]:indexPTt[k + 1]]
 			# Plot the enveloppe deduced from the error bars on T
-			plt.fill_between(x = ppt['TIMEH'], 
+			fig3 = plt.fill_between(x = ppt['TIMEH'], 
     		                 y1 = ppt['TEMPH'] + ppt['DTEMPH'],
     		                 y2 = ppt['TEMPH'] - ppt['DTEMPH'],
     		                 alpha=0.20, 
@@ -497,67 +499,173 @@ def plotTTp(inputdataPTt, outputdataPTt, graphpath = 'Graphs', graphtitle = None
     		                 interpolate=True,
     		                 label = 'Acceptable paths')
 			# plot the max enveloppe
-			plt.plot(ppt['TIMEH'],
+			fig3 = plt.plot(ppt['TIMEH'],
 			         ppt['TEMPH'] + ppt['DTEMPH'],
 					 marker = 'None', linestyle = '-', 
 				 	 color = 'lightblue', alpha = 1,
 					 label = 'Min-Max')
 			# Plot the min enveloppe
-			plt.plot(ppt['TIMEH'],
+			fig3 = plt.plot(ppt['TIMEH'],
 			         ppt['TEMPH'] - ppt['DTEMPH'],
 					 marker = 'None', linestyle = '-', 
 				 	 color = 'lightblue', alpha = 1)
 			# 	Plot the mean PT-t path
-			plt.plot(ppt['TIMEH'],
+			fig3 = plt.plot(ppt['TIMEH'],
 			         ppt['TEMPH'],
 					 marker = 'None', linestyle = '-', 
 				 	 color = 'blue', alpha = 1,
 					 label = 'Mean')
 			#	Plot the prediction
-			plt.plot(pptOut['TIME'],
+			fig3 = plt.plot(pptOut['TIME'],
 			         pptOut['TEMPPRED'],
 					 marker = 'None', linestyle = '-', 
 				 	 color = 'green', alpha = 1,
 					 label = 'Predictions')
 
 			#	Save the graph
-			plt.xlabel(u'Time before present (Ma)')
-			plt.ylabel(u'Temperature (Ma)')
-			plt.legend(loc = 'best')
-			plt.title(graphtitle)
+			fig3 = plt.xlabel(u'Time before present (Ma)')
+			fig3 = plt.ylabel(u'Temperature (Ma)')
+			fig3 = plt.legend(loc = 'best')
+			fig3 = plt.title(graphtitle)
 			# Invert x- and y-axis
-			plt.axis([max(ppt['TIMEH']), min(ppt['TIMEH']),
+			fig3 = plt.axis([max(ppt['TIMEH']), min(ppt['TIMEH']),
 					  max(ppt['TEMPH'] + ppt['DTEMPH']), min(ppt['TEMPH'] - ppt['DTEMPH'])])
-			plt.savefig(graphpath + '/TTpaths/' + graphtitle +'_ttpath_sample' + str(k+1) + '.pdf')
-			fig3.clear()
+			plt.figure(3).savefig(graphpath + '/TTpaths/' + graphtitle +'_ttpath_sample' + str(k+1) + '.pdf')
+			plt.figure(3).clear()
+			plt.close(plt.figure(3))
+		
+		if stackTT:
+			print('\tPlotting stacked PTt...')
+			fig5 = plt.figure(5)
+			for k in range (0, nPTtsamples):
+				#	Extract the PTt path from the file
+				if k == (nPTtsamples-1):
+					ppt = inputPTt[['TIMEH', 'TEMPH', 'DTEMPH']][indexPTt[k]:]
+					pptOut = outputPTt[['TIME', 'TEMP', 'TEMPPRED']][indexPTt[k]:]
+					# Plot the enveloppe deduced from the error bars on T
+					fig5 = plt.fill_between(x = ppt['TIMEH'], 
+    		    		             y1 = ppt['TEMPH'] + ppt['DTEMPH'],
+    		        		         y2 = ppt['TEMPH'] - ppt['DTEMPH'],
+    		            		     alpha=0.20, 
+    		                		 color='lightblue', 
+		    		                 interpolate=True,
+    				                 label = 'Acceptable paths')
+					# plot the max enveloppe
+					fig5 = plt.plot(ppt['TIMEH'],
+			    	    	    	ppt['TEMPH'] + ppt['DTEMPH'],
+						 			marker = 'None', linestyle = '-', 
+					 	 			color = 'lightblue', alpha = 1,
+						 			label = 'Min-Max')
+					# Plot the mean PT-t path
+					fig5 = plt.plot(ppt['TIMEH'],
+				         			ppt['TEMPH'],
+						 			marker = 'None', linestyle = '-', 
+					 	 			color = 'blue', alpha = 1,
+						 			label = 'Mean')
+					# Plot the prediction
+					fig5 = plt.plot(pptOut['TIME'],
+			         				pptOut['TEMPPRED'],
+					 				marker = 'None', linestyle = '-', 
+				 	 				color = 'green', alpha = 1,
+					 				label = 'Predictions')
+				else:
+					ppt = inputPTt[['TIMEH', 'TEMPH', 'DTEMPH']][indexPTt[k]:indexPTt[k + 1]]
+					pptOut = outputPTt[['TIME', 'TEMP', 'TEMPPRED']][indexPTt[k]:indexPTt[k + 1]]
+					# Plot the enveloppe deduced from the error bars on T
+					fig5 = plt.fill_between(x = ppt['TIMEH'], 
+    		    		             y1 = ppt['TEMPH'] + ppt['DTEMPH'],
+    		        		         y2 = ppt['TEMPH'] - ppt['DTEMPH'],
+    		            		     alpha=0.20, 
+	    		            	     color='lightblue', 
+    			                	 interpolate=True)
+					# plot the max enveloppe
+					fig5 = plt.plot(ppt['TIMEH'],
+			    		     ppt['TEMPH'] + ppt['DTEMPH'],
+							 marker = 'None', linestyle = '-', 
+					 		 color = 'lightblue', alpha = 1)
+					# Plot the min enveloppe
+					fig5 = plt.plot(ppt['TIMEH'],	
+				    	     		ppt['TEMPH'] - ppt['DTEMPH'],
+						 			marker = 'None', linestyle = '-', 
+				 		 			color = 'lightblue', alpha = 1)
+					# Plot the mean PT-t path
+					fig5 = plt.plot(ppt['TIMEH'],
+				    	     ppt['TEMPH'],
+							 marker = 'None', linestyle = '-', 
+						 	 color = 'blue', alpha = 1)
+					# Plot the prediction
+					fig5 = plt.plot(pptOut['TIME'],
+			    	     			pptOut['TEMPPRED'],
+						 			marker = 'None', linestyle = '-', 
+					 	 			color = 'green', alpha = 1)
+
+			#	Save the graph with stacked plots
+			fig5 = plt.xlabel(u'Time before present (Ma)')
+			fig5 = plt.ylabel(u'Temperature (Ma)')
+			fig5 = plt.legend(loc = 'best')
+			fig5 = plt.title(graphtitle)
+			# Invert x- and y-axis
+			fig5 = plt.axis([max(ppt['TIMEH']), min(ppt['TIMEH']),
+					  max(ppt['TEMPH'] + ppt['DTEMPH']), min(ppt['TEMPH'] - ppt['DTEMPH'])])
+			plt.figure(5).savefig(graphpath + '/TTpaths/' + graphtitle +'_ttpath_stacks.pdf')
+			plt.figure(5).clear()
+			plt.close(plt.figure(5))
 	else:
-		print('\033[91mWarning:\033[00m No PT-t paths to plot...')	
+		print('\t\033[91mWarning:\033[00m No PT-t paths to plot...')	
 
 	return
 
 
 #################################################
-def plotMTL():
+def plotMTL(inputdataFTL, outputdataFTL = None,
+			graphpath = 'Graphs', graphtitle = None):
 
-	print('\t\033[91mWarning:\033[00m MTL not implemented for now...')	
+	print('\t\t\033[91mWarning:\033[00m MTL not implemented for now...')	
 	
 	# TO DO
 
 	# Read input file
+	# Should be FTL_files.csv; Same way to read it than the TTp files ?
 
 	# Read Output file
+	# Comparison file is 'output/CompareFTL.csv'; Same way to read it than the TTp files ?
 
 	# Find number of sample with MTL
 	# For each sample with MTL,
-	#	Build input histogram
-	#	Build output histogram
-	#	Save the graph
+	#for k in range (0, nFTLsamples):
+	#	fig4 = plt.figure()
+	#	# Extract the PTt path from the file
+	#	# Build input histogram
+	#	n, bins, patches = plt.hist(x = input MTL, 
+	#                               bins = 10, #'auto', 'fd','doane', 'scott', 'stone', 'rice', 'sturges', 'sqrt'
+	#                               density = False, 
+	#								label = 'Observed MTL'
+	#                               facecolor='g', 
+	#                               alpha=0.75)
+	#	# Build output histogram
+	#	n, bins, patches = plt.hist(x = predicted MTL, 
+	#                               bins = 10, #'auto', 'fd','doane', 'scott', 'stone', 'rice', 'sturges', 'sqrt'
+	#                               density = False, 
+	#								label = 'Predicted MTL'
+	#                               facecolor='b', 
+	#                               alpha=0.3)
+	#	# Save the graph
+	#	plt.xlabel(u'Time before present (Ma)')
+	#	plt.ylabel(u'Temperature (Ma)')
+	#	plt.legend(loc = 'best')
+	#	plt.title(graphtitle)
+	#	# Invert x- and y-axis
+	#	plt.axis([max(ppt['TIMEH']), min(ppt['TIMEH']),
+	#			  max(ppt['TEMPH'] + ppt['DTEMPH']), min(ppt['TEMPH'] - ppt['DTEMPH'])])
+	#	plt.savefig(graphpath + '/TTpaths/' + graphtitle +'_ttpath_sample' + str(k+1) + '.pdf')
+	#	fig4.clear()
 
 	return
 
 #################################################
 ################# Main code #####################
-def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt = None,
+def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt = None, stackTT = True,
+					  inputdataFTL = None, outputdataFTL = None,
 					  dataplot = ['AHe','AFT'],
 					  graphpath = 'Graphs', graphtitle = None, agerange = None,
 					  profiletype = [], A = None, B = None,
@@ -578,7 +686,19 @@ def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt =
 									   Usually, this is 'output/CompareTT.csv'
 									   Need to be given if 'TTp' in dataplot
         							   Default = None
+		
+		inputdataFTL (str, optional): Path and file name of the input FTL data file 
+									  Need to be given if 'FTL' in dataplot
+        							  Default = None 
+		
+		stackTT (boolean, optional): Tells if we want to plot all the PTt path in one single graph
+									 Defaults to True
 
+    	outputdataFTL (str, optional): Path and file name of the output FTL prediction/comparison file
+									   Usually, this is 'output/CompareFTL.csv'
+									   Need to be given if 'FTL' in dataplot
+        							   Default = None
+		
 		dataplot (list, optional): List of data to plot ; By default, the altitude will be plotted
 				        		    Do not forget the simple quotes !!!
 						   			['AHe', 'AFT', 'ZHe', 'ZFT', 'KAr', 'MAr', 'BAr', 'MTL', 'TTp']
@@ -684,6 +804,7 @@ def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt =
 		agecol, errname, junk2, junk1, junk, profdict =  dict_pecube()
 
 	# Plot profiles
+	print('\x1b[32;1mPlotting profiles...\033[00m')
 	if profiletype:
 		if os.path.exists(graphpath + '/Profile') == False:
 			os.mkdir(graphpath + '/Profile')
@@ -710,7 +831,7 @@ def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt =
 	if os.path.exists(graphpath + '/Compare') == False:
 			os.mkdir(graphpath + '/Compare')
 	# Call plot function for altitude
-	#print(u'\tPlotting altitude comparison')
+	print(u'\x1b[32;1mPlotting observations - predictions comparison...\033[00m')
 	plotComparisons(inputdata = inputdata, dataplot = ['Altitude'],
                     datac = datac, inputc = inputc, 
 					agecol = agecol, errname = errname, colores = colores,
@@ -724,6 +845,7 @@ def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt =
 					agename = agename,
 					graphpath = graphpath, graphtitle = graphtitle)
 
+	print('\x1b[32;1mPlotting PTt paths...\033[00m')
 	# Check if input and output PTt path files are present
 	if (inputdataPTt and outputdataPTt) and (not os.path.isfile(inputdataPTt) or not os.path.isfile(outputdataPTt)):
 		print(u'\n \033[91mWarning:\033[00m No %s and/or %s file, I am skipping the PTt plot...\n' % (inputdataPTt, outputdataPTt))
@@ -732,23 +854,36 @@ def PlotPecubeForward(datafnme, inputdata, inputdataPTt = None, outputdataPTt =
 	if inputdataPTt and outputdataPTt and \
 	   ('TTp' in dataplot or 'Ttp' in dataplot or 'ttp' in dataplot or 'TTP' in dataplot or
 	    'tTP' in dataplot or 'ttP' in dataplot or 'TtP' in dataplot or 'tTp' in dataplot):
-		print('\tPlotting PTt paths')
 		if os.path.exists(graphpath + '/TTpaths') == False:
 			os.mkdir(graphpath + '/TTpaths')
 		# Call the plot PTt function
 		plotTTp(inputdataPTt = inputdataPTt, 
 		        outputdataPTt =outputdataPTt,
-				graphpath = graphpath, graphtitle = graphtitle)	
+				graphpath = graphpath, graphtitle = graphtitle, stackTT = True)	
 	else:
-		print('\033[91mWarning:\033[00m No PT-t paths to plot...')
+		print('\t\033[91mWarning:\033[00m No PT-t paths to plot...')
 
 	# TO DO !!!!
+	print('\x1b[32;1mPlotting MTL...\x1b[0m')
 	if ('MTL' in dataplot or 'MTl' in dataplot or 'mtl' in dataplot or 'mtL' in dataplot or
 	    'mTL' in dataplot or 'MtL' in dataplot or 'mtl' in dataplot or 'mTl' in dataplot):
-		print('\tPlotting MTL')
-		if os.path.exists(graphpath + '/MTL') == False:
-			os.mkdir(graphpath + '/MTL')
-		plotMTL()
+
+		# Check if FTL input files are there...
+		if (inputdataFTL and outputdataFTL) and (not os.path.isfile(inputdataFTL) or not os.path.isfile(outputdataFTL)):
+			print(u'\n \033[91mWarning:\033[00m No %s and/or %s file, I am skipping the PTt plot...\n' % (inputdataFLT, outputdataFTL))
+			#inputdataFTL = None
+			#outputdataFTL = None
+		else:
+			# Make the output folder in Graphs/
+			if os.path.exists(graphpath + '/MTL') == False:
+				os.mkdir(graphpath + '/MTL')
+			# Call the function to plot the MTL
+			# Input file, comparefile, 
+			plotMTL(inputdataFTL = inputdataFTL, 
+		    	    outputdataFTL =outputdataFTL,
+					graphpath = graphpath, graphtitle = graphtitle)
+	else:
+		print('\t\033[91mWarning:\033[00m No FTL data to plot...')
 	# END - TO DO !!!!
 
 	print('\n###########################################################################\n')
@@ -778,6 +913,11 @@ if __name__ == "__main__":
 	inputdata = '../Tests/Forward/Data/Trujillo.csv'
 	inputdataPTt = '../Tests/Forward/Data/TrujilloPTt.csv'
 	outputdataPTt = '../Tests/Forward/Data/TimeTemperaturePaths.csv'
+	inputdataFTL = '../Tests/Forward/Data/FTL_files.csv'
+	outputdataFTL = '../Tests/Forward/Data/CompareFLT.csv'
+
+	# Stack all the TT paths on a single graph
+	stackTT = True
 
 	# graphtitle: title to write on the graph
 	graphtitle = 'Trujillo transect'
@@ -813,6 +953,9 @@ if __name__ == "__main__":
 					  inputdata = inputdata,
 					  inputdataPTt = inputdataPTt,
 					  outputdataPTt = outputdataPTt,
+					  stackTT = stackTT,
+					  inputdataFTL = inputdataFTL,
+					  outputdataFTL = outputdataFTL,
 					  graphtitle = graphtitle,
 					  agerange = agerange,
 					  profiletype = profiletype,
